#ifdef E_TYPEDEFS
#else
#ifndef E_INT_CONFIG_MOUSEBINDINGS_H
#define E_INT_CONFIG_MOUSEBINDINGS_H

E_Config_Dialog *e_int_config_mousebindings(E_Container *con, const char *params __UNUSED__);

#endif
#endif
